@@ -1,7 +1,11 @@
 from dagster.core.utils import check_dagster_package_version
 
 from .constraints import RowCountConstraint, StrictColumnsConstraint
-from .data_frame import DataFrame, create_dagster_pandas_dataframe_type
+from .data_frame import (
+    DataFrame,
+    create_dagster_pandas_dataframe_type,
+    create_structured_dataframe_type,
+)
 from .validation import PandasColumn
 from .version import __version__
 
@@ -10,6 +14,7 @@ check_dagster_package_version('dagster-pandas', __version__)
 __all__ = [
     'DataFrame',
     'create_dagster_pandas_dataframe_type',
+    'create_structured_dataframe_type',
     'PandasColumn',
     'RowCountConstraint',
     'StrictColumnsConstraint',
